@@ -3,7 +3,7 @@ from cadquery import Assembly
 from cad_to_dagmc import CadToDagmc
 
 result = cq.Workplane().sphere(5)
-result2 = sphere = cq.Workplane().moveTo(10, 0).sphere(2)
+result2 = cq.Workplane().moveTo(10, 0).sphere(2)
 
 assembly = Assembly()
 assembly.add(result)
